# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [Unreleased]

### IMPORTANT
- **Switched from poetry to setuptools**

## Added
- Dataset template

## Changed

## Deleted

## [0.0.3]

## Fixes
- `load_data` caching

## [0.0.2]

## Added
- Added `trained_models` module
- `NUM_CLASSES` constant to datasets

## Changed
- Renamed `load` to `load_data`

## Deleted